@@ -1,5 +1,5 @@
 extern crate sysctl;
-
+#[cfg(not(target_os = "macos"))]
 fn main() {
 
     let ctl = "dev.cpu.0.temperature";
@@ -19,3 +19,7 @@ fn main() {
         panic!("Error, not a temperature ctl!")
     }
 }
+#[cfg(target_os = "macos")]
+fn main() {
+    
+}
\ No newline at end of file
