@@ -1,5 +1,5 @@
 extern crate sysctl;
-
+#[cfg(not(target_os = "macos"))]
 fn main() {
 
     let ctl = "kern.osrevision";
@@ -15,3 +15,8 @@ fn main() {
         println!("Value: {}", val);
     }
 }
+
+#[cfg(target_os = "macos")]
+fn main() {
+    
+}
\ No newline at end of file
